@@ -1,6 +1,6 @@
 /* airpcap_loader.c
  *
- * $Id: airpcap_loader.c 30945 2009-11-12 23:48:11Z gerald $
+ * $Id: airpcap_loader.c 33932 2010-08-26 16:04:07Z gerald $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -47,6 +47,7 @@
 #include <epan/strutil.h>
 #include <epan/frequency-utils.h>
 #include "capture_ui_utils.h"
+#include <wsutil/file_util.h>
 
 #include "simple_dialog.h"
 
@@ -2336,7 +2337,6 @@ set_on_off(pref_t *pref, gpointer ud)
     {
 	number = *pref->varp.boolp;
 
-	g_free((void *)*pref->varp.boolp);
 	if(*is_on)
 	    *pref->varp.boolp = TRUE;
 	else
@@ -2451,7 +2451,7 @@ int load_airpcap(void)
     gboolean base_functions = TRUE;
     gboolean eleven_n_functions = TRUE;
 
-    if((AirpcapLib =  LoadLibrary(TEXT("airpcap.dll"))) == NULL)
+    if((AirpcapLib = ws_load_library("airpcap.dll")) == NULL)
     {
   		/* Report the error but go on */
   		AirpcapVersion = AIRPCAP_DLL_NOT_FOUND;
