@@ -2,7 +2,7 @@
  * Routines for ISC DHCP Server failover protocol dissection
  * Copyright 2004, M. Ortega y Strupp <moys@loplof.de>
  *
- * $Id: packet-dhcp-failover.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-dhcp-failover.c 32913 2010-05-21 06:33:25Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,9 +39,7 @@
 # include "config.h"
 #endif
 
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include <glib.h>
 
@@ -53,13 +51,11 @@
 
 #define TCP_PORT_DHCPFO 519
 
-static unsigned int tcp_port_pref = TCP_PORT_DHCPFO;
+static guint tcp_port_pref = TCP_PORT_DHCPFO;
 
 /* desegmentation of DHCP failover over TCP */
 static gboolean dhcpfo_desegment = TRUE;
 
-static dissector_handle_t dhcpfo_handle;
-
 /* Initialize the protocol and registered fields */
 static int proto_dhcpfo = -1;
 static int hf_dhcpfo_length = -1;
@@ -379,10 +375,8 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint32 max_unacked_bndupd, receive_timer;
 
 /* Make entries in Protocol column and Info column on summary display */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "DHCPFO");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DHCPFO");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	length = tvb_get_ntohs(tvb, offset);
 	if (tree) {
@@ -450,7 +444,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		timex.nsecs = 0;
 		proto_tree_add_time_format_value(dhcpfo_tree, hf_dhcpfo_time, tvb,
 		    offset, 4, &timex, "%s",
-		    abs_time_secs_to_str(timex.secs));
+		    abs_time_secs_to_str(timex.secs, ABSOLUTE_TIME_LOCAL, TRUE));
 	}
 	offset += 4;
 
@@ -673,7 +667,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			lease_expiration_time =
 			    tvb_get_ntohl(tvb, offset);
 			lease_expiration_time_str =
-			    abs_time_secs_to_str(lease_expiration_time);
+			    abs_time_secs_to_str(lease_expiration_time, ABSOLUTE_TIME_LOCAL, TRUE);
 
 			proto_item_append_text(oi, ", %s",
 			    lease_expiration_time_str);
@@ -697,7 +691,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			    tvb_get_ntohl(tvb, offset);
 
 			potential_expiration_time_str =
-			    abs_time_secs_to_str(potential_expiration_time);
+			    abs_time_secs_to_str(potential_expiration_time, ABSOLUTE_TIME_LOCAL, TRUE);
 
 			proto_item_append_text(oi, ", %s",
 			    potential_expiration_time_str);
@@ -721,7 +715,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			    tvb_get_ntohl(tvb, offset);
 
 			grace_expiration_time_str =
-			    abs_time_secs_to_str(grace_expiration_time);
+			    abs_time_secs_to_str(grace_expiration_time, ABSOLUTE_TIME_LOCAL, TRUE);
 
 			proto_item_append_text(oi, ", %s",
 			    grace_expiration_time_str);
@@ -744,7 +738,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			client_last_transaction_time =
 			    tvb_get_ntohl(tvb, offset);
 			client_last_transaction_time_str =
-			    abs_time_secs_to_str(client_last_transaction_time);
+			    abs_time_secs_to_str(client_last_transaction_time, ABSOLUTE_TIME_LOCAL, TRUE);
 
 			proto_item_append_text(oi, ", %s",
 			    client_last_transaction_time_str);
@@ -754,7 +748,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			    offset, option_length,
 			    client_last_transaction_time,
 			    "%s",
-			    abs_time_secs_to_str(client_last_transaction_time));
+			    abs_time_secs_to_str(client_last_transaction_time, ABSOLUTE_TIME_LOCAL, TRUE));
 			break;
 
 		case DHCP_FO_PD_START_TIME_OF_STATE:
@@ -767,7 +761,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			start_time_of_state =
 			    tvb_get_ntohl(tvb, offset);
 			start_time_of_state_str =
-			    abs_time_secs_to_str(start_time_of_state);
+			    abs_time_secs_to_str(start_time_of_state, ABSOLUTE_TIME_LOCAL, TRUE);
 
 			proto_item_append_text(oi, ", %s",
 			    start_time_of_state_str);
@@ -777,7 +771,7 @@ dissect_dhcpfo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			    offset, option_length,
 			    start_time_of_state,
 			    "%s",
-			    abs_time_secs_to_str(start_time_of_state));
+			    abs_time_secs_to_str(start_time_of_state, ABSOLUTE_TIME_LOCAL, TRUE));
 			break;
 
 		case DHCP_FO_PD_SERVERSTATE:
@@ -954,22 +948,10 @@ dissect_dhcpfo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    get_dhcpfo_pdu_len, dissect_dhcpfo_pdu);
 }
 
-void
-proto_reg_handoff_dhcpfo(void)
-{
-	static gboolean initialized = FALSE;
-	static unsigned int port = 0;
-
-	if (initialized) {
-		dissector_delete("tcp.port", port, dhcpfo_handle);
-	} else {
-		initialized = TRUE;
-	}
-	port = tcp_port_pref;
-	dissector_add("tcp.port", tcp_port_pref, dhcpfo_handle);
-}
-
 /* Register the protocol with Wireshark */
+
+void proto_reg_handoff_dhcpfo(void);
+
 void
 proto_register_dhcpfo(void)
 {
@@ -979,208 +961,208 @@ proto_register_dhcpfo(void)
 		{ &hf_dhcpfo_length,
 			{ "Message length",	   "dhcpfo.length",
 			FT_UINT16, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_dhcpfo_type,
 			{ "Message Type",	   "dhcpfo.type",
 			FT_UINT8, BASE_DEC, VALS(failover_vals), 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_poffset,
 			{ "Payload Offset",	   "dhcpfo.poffset",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_time,
 			{ "Time",	   "dhcpfo.time",
-			FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0,
-			"", HFILL }
+			FT_ABSOLUTE_TIME, ABSOLUTE_TIME_LOCAL, NULL, 0,
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_xid,
 			{ "Xid",	   "dhcpfo.xid",
 			FT_UINT32, BASE_HEX, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_additional_HB,
 			{"Additional Header Bytes",	"dhcpfo.additionalheaderbytes",
 			FT_BYTES, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_payload_data,
 			{"Payload Data",	"dhcpfo.payloaddata",
 			FT_NONE, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_dhcp_style_option,
 			{"DHCP Style Option",	"dhcpfo.dhcpstyleoption",
 			FT_NONE, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{ &hf_dhcpfo_option_code,
 			{"Option Code",		"dhcpfo.optioncode",
 			FT_UINT16, BASE_DEC, VALS(option_code_vals), 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_option_length,
 			{"Length",		"dhcpfo.optionlength",
 			FT_UINT16, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_binding_status,
 			{"Type", "dhcpfo.bindingstatus",
 			FT_UINT32, BASE_DEC, VALS(binding_status_vals), 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 
 		{&hf_dhcpfo_server_state,
 			{"server status", "dhcpfo.serverstatus",
 			FT_UINT8, BASE_DEC, VALS(server_state_vals), 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 
 		{&hf_dhcpfo_assigned_ip_address,
 			{"assigned ip address", "dhcpfo.assignedipaddress",
 			FT_IPv4, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_sending_server_ip_address,
 			{"sending server ip-address", "dhcpfo.sendingserveripaddress",
 			FT_IPv4, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 
 		{&hf_dhcpfo_addresses_transferred,
 			{"addresses transferred", "dhcpfo.addressestransferred",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 
 		{&hf_dhcpfo_client_identifier,
 			{"Client Identifier", "dhcpfo.clientidentifier",
 			FT_STRING, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_client_hw_type,
 			{"Client Hardware Type", "dhcpfo.clienthardwaretype",
 			FT_UINT8, BASE_HEX, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{&hf_dhcpfo_client_hardware_address,
 			{"Client Hardware Address", "dhcpfo.clienthardwareaddress",
 			FT_BYTES, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_ftddns,
 			{"FTDDNS", "dhcpfo.ftddns",
 			FT_STRING, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_reject_reason,
 			{"Reject reason", "dhcpfo.rejectreason",
 			FT_UINT8, BASE_DEC, VALS(reject_reason_vals), 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_message,
 			{"Message", "dhcpfo.message",
 			FT_STRING, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 
 		{&hf_dhcpfo_mclt,
 			{"MCLT", "dhcpfo.mclt",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_vendor_class,
 			{"Vendor class", "dhcpfo.vendorclass",
 			FT_STRING, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_lease_expiration_time,
 			{"Lease expiration time", "dhcpfo.leaseexpirationtime",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_grace_expiration_time,
 			{"Grace expiration time", "dhcpfo.graceexpirationtime",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_potential_expiration_time,
 			{"Potential expiration time", "dhcpfo.potentialexpirationtime",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_client_last_transaction_time,
 			{"Client last transaction time", "dhcpfo.clientlasttransactiontime",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_start_time_of_state,
 			{"Start time of state", "dhcpfo.starttimeofstate",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_vendor_option,
 			{"Vendor option", "dhcpfo.vendoroption",
 			FT_NONE, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_max_unacked_bndupd,
 			{"Max unacked BNDUPD", "dhcpfo.maxunackedbndupd",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_protocol_version,
 			{"Protocol version", "dhcpfo.protocolversion",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_receive_timer,
 			{"Receive timer", "dhcpfo.receivetimer",
 			FT_UINT32, BASE_DEC, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_message_digest,
 			{"Message digest", "dhcpfo.messagedigest",
 			FT_STRING, BASE_NONE, NULL, 0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 
 		{&hf_dhcpfo_hash_bucket_assignment,
 			{"Hash bucket assignment", "dhcpfo.hashbucketassignment",
-			FT_BYTES, BASE_HEX, NULL, 0,
-			"", HFILL }
+			FT_BYTES, BASE_NONE, NULL, 0,
+			NULL, HFILL }
 		},
 	};
 
@@ -1201,8 +1183,6 @@ proto_register_dhcpfo(void)
 	proto_register_field_array(proto_dhcpfo, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	dhcpfo_handle = create_dissector_handle(dissect_dhcpfo, proto_dhcpfo);
-
 	dhcpfo_module = prefs_register_protocol(proto_dhcpfo, proto_reg_handoff_dhcpfo);
 	prefs_register_uint_preference(dhcpfo_module, "tcp_port",
 		"DHCP failover TCP Port", "Set the port for DHCP failover communications",
@@ -1213,3 +1193,21 @@ proto_register_dhcpfo(void)
 	    " To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
 	    &dhcpfo_desegment);
 }
+
+void
+proto_reg_handoff_dhcpfo(void)
+{
+	static gboolean initialized = FALSE;
+	static dissector_handle_t dhcpfo_handle;
+	static guint saved_tcp_port;
+
+	if (!initialized) {
+		dhcpfo_handle = create_dissector_handle(dissect_dhcpfo, proto_dhcpfo);
+		initialized = TRUE;
+	} else {
+		dissector_delete("tcp.port", saved_tcp_port, dhcpfo_handle);
+	}
+	dissector_add("tcp.port", tcp_port_pref, dhcpfo_handle);
+	saved_tcp_port = tcp_port_pref;
+}
+
