@@ -4,7 +4,7 @@
  * http://www.packetcable.com/downloads/specs/pkt-sp-esp-I01-991229.pdf
  * Chapter 4 ( Call Content Connection Interface )
  *
- * $Id: packet-pcli.c 30124 2009-09-24 19:50:43Z krj $
+ * $Id: packet-pcli.c 32410 2010-04-06 21:14:01Z wmeier $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  *
@@ -33,11 +33,9 @@
 #include "config.h"
 #endif
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <time.h>
-#include <string.h>
 
 #include <glib.h>
 #include <epan/packet.h>
