@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: wslua_dumper.c 33716 2010-08-05 16:44:50Z etxrab $
+ * $Id: wslua_dumper.c 34889 2010-11-15 21:38:16Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -241,7 +241,7 @@ WSLUA_METHOD Dumper_close(lua_State* L) {
     }
 
 	/* this way if we close a dumper any attempt to use it (for everything but GC) will yield an error */
-	dp = NULL;
+	*dp = NULL;
 
     return 0;
 }
