@@ -1,6 +1,6 @@
 /* airpcap_gui_utils.c
  *
- * $Id: airpcap_gui_utils.c 28709 2009-06-11 18:38:15Z gerald $
+ * $Id: airpcap_gui_utils.c 30945 2009-11-12 23:48:11Z gerald $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -33,6 +33,7 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 
+#include <stdio.h>
 #include <string.h>
 
 #include <epan/filesystem.h>
@@ -128,7 +129,7 @@ airpcap_set_toolbar_start_capture(airpcap_if_info_t* if_info)
 		}
 
 		airpcap_update_channel_combo(GTK_WIDGET(toolbar_channel_cb),if_info);
-		airpcap_update_channel_offset_combo(if_info, if_info->channelInfo.Frequency, airpcap_toolbar_channel_offset);
+		airpcap_update_channel_offset_combo(if_info, if_info->channelInfo.Frequency, airpcap_toolbar_channel_offset, TRUE);
 		change_airpcap_settings = TRUE;
     }
     else /* Current interface is NOT an AirPcap one... */
@@ -146,7 +147,6 @@ airpcap_set_toolbar_start_capture(airpcap_if_info_t* if_info)
 		gtk_widget_set_sensitive(airpcap_toolbar_decryption,FALSE);
 		gtk_widget_set_sensitive(airpcap_toolbar_decryption_lb,FALSE);
 		gtk_widget_set_sensitive(airpcap_toolbar_keys_button,FALSE);
-		airpcap_set_toolbar_no_if(airpcap_tb);
     }
 }
 
@@ -224,7 +224,7 @@ airpcap_set_toolbar_stop_capture(airpcap_if_info_t* if_info)
   		}
 
   		airpcap_update_channel_combo(GTK_WIDGET(toolbar_channel_cb),if_info);
-  		airpcap_update_channel_offset_combo(if_info, if_info->channelInfo.Frequency, airpcap_toolbar_channel_offset);
+  		airpcap_update_channel_offset_combo(if_info, if_info->channelInfo.Frequency, airpcap_toolbar_channel_offset, TRUE);
   		change_airpcap_settings = TRUE;
   	}
     else
@@ -242,7 +242,6 @@ airpcap_set_toolbar_stop_capture(airpcap_if_info_t* if_info)
   		gtk_widget_set_sensitive(airpcap_toolbar_decryption,TRUE);
   		gtk_widget_set_sensitive(airpcap_toolbar_decryption_lb,TRUE);
   		gtk_widget_set_sensitive(airpcap_toolbar_keys_button,TRUE);
-  		airpcap_set_toolbar_no_if(airpcap_tb);
   		change_airpcap_settings = FALSE;
     }
 }
@@ -386,22 +385,19 @@ airpcap_fill_key_list(GtkWidget *keylist)
 AirpcapValidationType
 airpcap_get_validation_type(const gchar* name)
 {
-    if(!(g_ascii_strcasecmp(AIRPCAP_VALIDATION_TYPE_NAME_ALL,name)))
-    {
-	return AIRPCAP_VT_ACCEPT_EVERYTHING;
-    }
-    else if(!(g_ascii_strcasecmp(AIRPCAP_VALIDATION_TYPE_NAME_CORRECT,name)))
-    {
-	return AIRPCAP_VT_ACCEPT_CORRECT_FRAMES;
-    }
-    else if(!(g_ascii_strcasecmp(AIRPCAP_VALIDATION_TYPE_NAME_CORRUPT,name)))
-    {
-	return AIRPCAP_VT_ACCEPT_CORRUPT_FRAMES;
-    }
-    else
-    {
+	if(!(g_ascii_strcasecmp(AIRPCAP_VALIDATION_TYPE_NAME_ALL,name)))
+	{
+		return AIRPCAP_VT_ACCEPT_EVERYTHING;
+	}
+	else if(!(g_ascii_strcasecmp(AIRPCAP_VALIDATION_TYPE_NAME_CORRECT,name)))
+	{
+		return AIRPCAP_VT_ACCEPT_CORRECT_FRAMES;
+	}
+	else if(!(g_ascii_strcasecmp(AIRPCAP_VALIDATION_TYPE_NAME_CORRUPT,name)))
+	{
+		return AIRPCAP_VT_ACCEPT_CORRUPT_FRAMES;
+	}
 	return AIRPCAP_VT_UNKNOWN;
-    }
 }
 
 /*
@@ -411,23 +407,23 @@ airpcap_get_validation_type(const gchar* name)
 gchar*
 airpcap_get_validation_name(AirpcapValidationType vt)
 {
-    if(vt == AIRPCAP_VT_ACCEPT_EVERYTHING)
-    {
-	return AIRPCAP_VALIDATION_TYPE_NAME_ALL;
-    }
-    else if(vt == AIRPCAP_VT_ACCEPT_CORRECT_FRAMES)
-    {
-	return AIRPCAP_VALIDATION_TYPE_NAME_CORRECT;
-    }
-    else if(vt == AIRPCAP_VT_ACCEPT_CORRUPT_FRAMES)
-    {
-	return AIRPCAP_VALIDATION_TYPE_NAME_CORRUPT;
-    }
-    else if(vt == AIRPCAP_VT_UNKNOWN)
-    {
-	return AIRPCAP_VALIDATION_TYPE_NAME_UNKNOWN;
-    }
-    return NULL;
+	if(vt == AIRPCAP_VT_ACCEPT_EVERYTHING)
+	{
+		return AIRPCAP_VALIDATION_TYPE_NAME_ALL;
+	}
+	else if(vt == AIRPCAP_VT_ACCEPT_CORRECT_FRAMES)
+	{
+		return AIRPCAP_VALIDATION_TYPE_NAME_CORRECT;
+	}
+	else if(vt == AIRPCAP_VT_ACCEPT_CORRUPT_FRAMES)
+	{
+		return AIRPCAP_VALIDATION_TYPE_NAME_CORRUPT;
+	}
+	else if(vt == AIRPCAP_VT_UNKNOWN)
+	{
+		return AIRPCAP_VALIDATION_TYPE_NAME_UNKNOWN;
+	}
+	return NULL;
 }
 
 /*
@@ -486,31 +482,6 @@ airpcap_get_link_name(AirpcapLinkType lt)
     return NULL;
 }
 
-/*
- * Sets the entry of the link type combo using the AirpcapLinkType.
- */
-void
-airpcap_link_type_combo_set_by_type(GtkWidget* c, AirpcapLinkType type)
-{
-    gchar* s;
-
-    s = airpcap_get_link_name(type);
-    gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(c)->entry),s);
-}
-
-/*
- * Retrieves the name in link type the combo entry.
- */
-AirpcapLinkType
-airpcap_link_type_combo_get_type(GtkWidget* c)
-{
-    const gchar* s;
-
-    s = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(c)->entry));
-
-    return airpcap_get_link_type(s);
-}
-
 /*
  * Sets the entry of the validation combo using the AirpcapValidationType.
  */
@@ -549,7 +520,7 @@ airpcap_channel_combo_set_by_frequency(GtkWidget* cb, guint chan_freq)
 /*
  * Change channel of Airpcap Adapter
  */
-gboolean
+static gboolean
 airpcap_update_frequency_and_offset(airpcap_if_info_t* if_info)
 {
     gchar ebuf[AIRPCAP_ERRBUF_SIZE];
@@ -569,24 +540,44 @@ airpcap_update_frequency_and_offset(airpcap_if_info_t* if_info)
 }
 
 /*
- * Changed callback for the channel combobox
+ * Changed callback for the channel combobox - common routine
  */
-void
-airpcap_channel_changed_cb(GtkWidget *channel_cb, gpointer channel_offset_cb)
+static void
+airpcap_channel_changed_common(GtkWidget *channel_cb, gpointer channel_offset_cb, gboolean set)
 {
     gint cur_chan_idx;
 
     if (channel_cb && channel_offset_cb && change_airpcap_settings && airpcap_if_active) {
         cur_chan_idx = gtk_combo_box_get_active(GTK_COMBO_BOX(channel_cb));
         if (cur_chan_idx >= 0 && cur_chan_idx < (gint) airpcap_if_active->numSupportedChannels) {
-            airpcap_if_active->channelInfo.Frequency = airpcap_if_active->pSupportedChannels[cur_chan_idx].Frequency;
+            if (set) {
+                airpcap_if_active->channelInfo.Frequency = airpcap_if_active->pSupportedChannels[cur_chan_idx].Frequency;
+            }
             airpcap_update_channel_offset_combo(airpcap_if_active,
                     airpcap_if_active->channelInfo.Frequency,
-                    GTK_WIDGET(channel_offset_cb));
-	}
+                    GTK_WIDGET(channel_offset_cb), set);
+    	}
     }
 }
 
+/*
+ * Changed callback for the channel combobox - set channel and offset
+ */
+void
+airpcap_channel_changed_set_cb(GtkWidget *channel_cb, gpointer channel_offset_cb)
+{
+    airpcap_channel_changed_common(channel_cb, channel_offset_cb, TRUE);
+}
+
+/*
+ * Changed callback for the channel combobox - don't set channel and offset
+ */
+void
+airpcap_channel_changed_noset_cb(GtkWidget *channel_cb, gpointer channel_offset_cb)
+{
+    airpcap_channel_changed_common(channel_cb, channel_offset_cb, FALSE);
+}
+
 static int
 airpcap_get_selected_channel_offset(GtkWidget *channel_offset_cb) {
     int offset;
@@ -604,7 +595,7 @@ airpcap_get_selected_channel_offset(GtkWidget *channel_offset_cb) {
         if (airpcap_if_selected != NULL)
         {
             sscanf(off_str, "%d", &offset);
-            if (offset >= -1 && offset <= -1) {
+            if (offset >= -1 && offset <= 1) {
                 retval = offset;
             }
         }
@@ -621,6 +612,12 @@ airpcap_channel_offset_changed_cb(GtkWidget *channel_offset_cb, gpointer data _U
 {
     airpcap_if_selected->channelInfo.ExtChannel = airpcap_get_selected_channel_offset(channel_offset_cb);
     airpcap_if_selected->saved = FALSE;
+	change_airpcap_settings = TRUE;
+	if (!airpcap_update_frequency_and_offset(airpcap_if_selected)){
+		simple_dialog(ESD_TYPE_ERROR,ESD_BTN_OK,
+					  "Unable to set extension channel %d",
+					  airpcap_if_selected->channelInfo.ExtChannel);
+	}
 }
 
 
@@ -628,7 +625,7 @@ airpcap_channel_offset_changed_cb(GtkWidget *channel_offset_cb, gpointer data _U
  * Update the channel offset of the given combobox according to the given frequency.
  */
 void
-airpcap_update_channel_offset_combo(airpcap_if_info_t* if_info, guint32 chan_freq, GtkWidget *channel_offset_cb)
+airpcap_update_channel_offset_combo(airpcap_if_info_t* if_info, guint chan_freq, GtkWidget *channel_offset_cb, gboolean set)
 {
     gint current_offset;
     gint new_offset;
@@ -642,13 +639,15 @@ airpcap_update_channel_offset_combo(airpcap_if_info_t* if_info, guint32 chan_fre
         return;
     }
 
-    new_offset = current_offset = airpcap_get_selected_channel_offset(channel_offset_cb);
+    new_offset = current_offset = if_info->channelInfo.ExtChannel;
 
     /* Clear out the list */
     while (gtk_tree_model_iter_n_children(gtk_combo_box_get_model(GTK_COMBO_BOX(channel_offset_cb)), NULL) > 0) {
         gtk_combo_box_remove_text(GTK_COMBO_BOX(channel_offset_cb), 0);
     }
 
+    gtk_widget_set_sensitive(GTK_WIDGET(channel_offset_cb), TRUE);
+
     for (i = 0; i < if_info->numSupportedChannels; i++) {
         if (if_info->pSupportedChannels[i].Frequency == chan_freq) {
 
@@ -685,11 +684,13 @@ airpcap_update_channel_offset_combo(airpcap_if_info_t* if_info, guint32 chan_fre
     gtk_combo_box_set_active(GTK_COMBO_BOX(channel_offset_cb), active_idx);
 
 
-    change_airpcap_settings = TRUE;
-
-    if_info->channelInfo.ExtChannel = new_offset;
-    if (!airpcap_update_frequency_and_offset(if_info)){
-        simple_dialog(ESD_TYPE_ERROR,ESD_BTN_OK,"Adapter failed to be set with the following settings: Frequency - %d   Extension Channel - %d", if_info->channelInfo.Frequency, if_info->channelInfo.ExtChannel);
+    if (set) {
+        change_airpcap_settings = TRUE;
+    
+        if_info->channelInfo.ExtChannel = new_offset;
+        if (!airpcap_update_frequency_and_offset(if_info)){
+            simple_dialog(ESD_TYPE_ERROR,ESD_BTN_OK,"Adapter failed to be set with the following settings: Frequency - %d   Extension Channel - %d", if_info->channelInfo.Frequency, if_info->channelInfo.ExtChannel);
+        }
     }
     
     if (idx_count < 1) {
@@ -753,7 +754,7 @@ airpcap_add_keys_from_list(GtkWidget *key_ls, airpcap_if_info_t *if_info _U_)
     guint i, j;
     gchar s[3];
     PAirpcapKeysCollection KeysCollection;
-    guint32 KeysCollectionSize;
+    guint KeysCollectionSize;
     guint8 KeyByte;
 
     guint keys_in_list = 0;
@@ -807,7 +808,7 @@ airpcap_add_keys_from_list(GtkWidget *key_ls, airpcap_if_info_t *if_info _U_)
 	/* Retrieve the Item corresponding to the i-th key */
 	new_key = g_string_new(row_key);
 
-	KeysCollection->Keys[i].KeyLen = new_key->len / 2;
+	KeysCollection->Keys[i].KeyLen = (guint) new_key->len / 2;
 	memset(&KeysCollection->Keys[i].KeyData, 0, sizeof(KeysCollection->Keys[i].KeyData));
 
 	for(j = 0 ; j < new_key->len; j += 2)
@@ -847,7 +848,7 @@ airpcap_add_keys_to_driver_from_list(GtkWidget *key_ls,airpcap_if_info_t *fake_i
     guint i, j;
     gchar s[3];
     PAirpcapKeysCollection KeysCollection;
-    guint32 KeysCollectionSize;
+    guint KeysCollectionSize;
     guint8 KeyByte;
 
     guint keys_in_list = 0;
@@ -904,7 +905,7 @@ airpcap_add_keys_to_driver_from_list(GtkWidget *key_ls,airpcap_if_info_t *fake_i
 	/* Retrieve the Item corresponding to the i-th key */
 	new_key = g_string_new(row_key);
 
-	KeysCollection->Keys[i].KeyLen = new_key->len / 2;
+	KeysCollection->Keys[i].KeyLen = (guint) new_key->len / 2;
 	memset(&KeysCollection->Keys[i].KeyData, 0, sizeof(KeysCollection->Keys[i].KeyData));
 
 	/* Key must be saved in adifferent way, depending on its type... */
@@ -977,7 +978,7 @@ airpcap_read_and_save_decryption_keys_from_clist(GtkWidget* key_ls, airpcap_if_i
 	    tmp_dk->key = g_string_new(tmp_key);
 	    tmp_dk->ssid = NULL;
 	    tmp_dk->type = AIRPDCAP_KEY_TYPE_WEP;
-	    tmp_dk->bits = tmp_dk->key->len * 4;
+	    tmp_dk->bits = (guint) tmp_dk->key->len * 4;
 	    key_list = g_list_append(key_list,tmp_dk);
 	}
 	else if(g_ascii_strcasecmp(tmp_type,AIRPCAP_WPA_PWD_KEY_STRING) == 0)
@@ -1188,7 +1189,7 @@ airpcap_enable_toolbar_widgets(GtkWidget* w, gboolean en)
 
     if_description_lb	= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_INTERFACE_KEY);
     channel_lb			= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_LABEL_KEY);
-    toolbar_channel_cb			= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_KEY);
+    toolbar_channel_cb  = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_KEY);
     channel_offset_cb	= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_OFFSET_KEY);
     channel_offset_lb	= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_OFFSET_LABEL_KEY);
     fcs_lb				= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_FCS_FILTER_LABEL_KEY);
@@ -1208,48 +1209,17 @@ airpcap_enable_toolbar_widgets(GtkWidget* w, gboolean en)
     return;
 }
 
-/*
- * This function sets up the correct airpcap toolbar that must
- * be displayed when no airpcap if is found on the system...
- */
-void
-airpcap_set_toolbar_no_if(GtkWidget* w)
-{
-    GtkWidget	*toolbar_tb,
-		*if_description_lb,
-		*toolbar_channel_cb,
-		*channel_lb,
-    *channel_offset_cb,
-		*channel_offset_lb,
-		*fcs_cb,
-		*fcs_lb,
-		*advanced_bt;
-
-    if(w == NULL)
-	return;
-
-    toolbar_tb = w;
-
-    if_description_lb	    = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_INTERFACE_KEY);
-    channel_lb			      = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_LABEL_KEY);
-    toolbar_channel_cb			      = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_KEY);
-    channel_offset_lb			= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_OFFSET_LABEL_KEY);
-    channel_offset_cb			= g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_CHANNEL_OFFSET_KEY);
-    fcs_lb				        = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_FCS_FILTER_LABEL_KEY);
-    fcs_cb				        = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_FCS_FILTER_KEY);
-    advanced_bt			      = g_object_get_data(G_OBJECT(toolbar_tb),AIRPCAP_TOOLBAR_ADVANCED_KEY);
-
-    if(fcs_cb != NULL)				gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(fcs_cb)->entry),"");
-    if(toolbar_channel_cb != NULL)		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(toolbar_channel_cb)->entry),"");
-    if(channel_offset_cb != NULL)			gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(channel_offset_cb)->entry),"");
-    if(if_description_lb != NULL)	gtk_label_set_text(GTK_LABEL(if_description_lb),"Current Wireless Interface: None");
-
-    /*if(if_description_lb != NULL)	gtk_widget_set_sensitive(if_description_lb,FALSE);
-    if(channel_lb != NULL)			gtk_widget_set_sensitive(channel_lb,FALSE);
-    if(channel_cb != NULL)			gtk_widget_set_sensitive(channel_cb,FALSE);
-    if(fcs_lb != NULL)				gtk_widget_set_sensitive(fcs_lb,FALSE);
-    if(fcs_cb != NULL)				gtk_widget_set_sensitive(fcs_cb,FALSE);
-    if(advanced_bt != NULL)			gtk_widget_set_sensitive(advanced_bt,FALSE);*/
-}
-
 #endif /* HAVE_AIRPCAP */
+
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 4
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ *
+ * vi: set shiftwidth=4 tabstop=4 expandtab
+ * :indentSize=4:tabSize=4:noTabs=true:
+ */
