@@ -1,7 +1,7 @@
 /* airopeek9.c
  * Routines for opening EtherPeek and AiroPeek V9 files
  *
- * $Id: airopeek9.c 26175 2008-09-11 03:37:16Z guy $
+ * $Id: airopeek9.c 32015 2010-02-26 07:59:54Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -84,12 +84,15 @@ typedef struct airopeek_utime {
 	guint32 lower;
 } airopeek_utime;
 
+typedef struct {
+	gboolean	has_fcs;
+} airopeek9_t;
+
 static gboolean airopeekv9_read(wtap *wth, int *err, gchar **err_info,
     gint64 *data_offset);
 static gboolean airopeekv9_seek_read(wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header, guchar *pd, int length,
     int *err, gchar **err_info);
-static void airopeekv9_close(wtap *wth);
 
 static int wtap_file_read_pattern (wtap *wth, const char *pattern, int *err)
 {
@@ -146,7 +149,7 @@ static int wtap_file_read_till_separator (wtap *wth, char *buffer, int buflen,
 		return -1;	/* error */
 	    }
 	}
-	if (strchr (separators, c))
+	if (strchr (separators, c) != NULL)
 	{
 	    *cp = '\0';
 	    break;
@@ -173,9 +176,9 @@ static int wtap_file_read_number (wtap *wth, guint32 *num, int *err)
 	return ret;
     }
     value = strtoul (str_num, &p, 10);
-    if (p == str_num || value > UINT_MAX)
+    if (p == str_num || value > G_MAXUINT32)
 	return 0;
-    *num = value;
+    *num = (guint32)value;
     return 1;
 }
 
@@ -195,6 +198,7 @@ int airopeek9_open(wtap *wth, int *err, gchar **err_info)
 	WTAP_ENCAP_IEEE_802_11_WITH_RADIO
     };
     #define NUM_AIROPEEK9_ENCAPS (sizeof airopeek9_encap / sizeof airopeek9_encap[0])
+    airopeek9_t *airopeek9;
 
     wtap_file_read_unknown_bytes(&ap_hdr, sizeof(ap_hdr), wth->fh, err);
 
@@ -307,20 +311,20 @@ int airopeek9_open(wtap *wth, int *err, gchar **err_info)
     wth->file_encap = file_encap;
     wth->subtype_read = airopeekv9_read;
     wth->subtype_seek_read = airopeekv9_seek_read;
-    wth->subtype_close = airopeekv9_close;
     wth->tsprecision = WTAP_FILE_TSPREC_NSEC;
 
-    wth->capture.airopeek9 = g_malloc(sizeof(airopeek9_t));
+    airopeek9 = (airopeek9_t *)g_malloc(sizeof(airopeek9_t));
+    wth->priv = (void *)airopeek9;
     switch (mediaSubType) {
 
     case AIROPEEK_V9_NST_ETHERNET:
     case AIROPEEK_V9_NST_802_11:
     case AIROPEEK_V9_NST_802_11_2:
-	wth->capture.airopeek9->has_fcs = FALSE;
+	airopeek9->has_fcs = FALSE;
 	break;
 
     case AIROPEEK_V9_NST_802_11_WITH_FCS:
-	wth->capture.airopeek9->has_fcs = TRUE;
+	airopeek9->has_fcs = TRUE;
 	break;
     }
 
@@ -349,7 +353,7 @@ static int
 airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
     gchar **err_info)
 {
-    long header_len = 0;
+    int header_len = 0;
     int bytes_read;
     guint8 tag_value[6];
     guint16 tag;
@@ -376,9 +380,9 @@ airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
 			*err = WTAP_ERR_SHORT_READ;
 		}
 	    }
-	    return -1;
+	    return 0;
 	}
-	header_len += sizeof(tag_value);
+	header_len += (int) sizeof(tag_value);
 	tag = pletohs(&tag_value[0]);
 	switch (tag) {
 
@@ -386,7 +390,7 @@ airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
 	    if (saw_length) {
 		*err = WTAP_ERR_BAD_RECORD;
 		*err_info = g_strdup("airopeekv9: record has two length fields");
-		return FALSE;
+		return 0;
 	    }
 	    hdr_info->length = pletohl(&tag_value[2]);
 	    saw_length = TRUE;
@@ -396,7 +400,7 @@ airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
 	    if (saw_timestamp_lower) {
 		*err = WTAP_ERR_BAD_RECORD;
 		*err_info = g_strdup("airopeekv9: record has two timestamp-lower fields");
-		return FALSE;
+		return 0;
 	    }
 	    hdr_info->timestamp.lower = pletohl(&tag_value[2]);
 	    saw_timestamp_lower = TRUE;
@@ -406,7 +410,7 @@ airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
 	    if (saw_timestamp_upper) {
 		*err = WTAP_ERR_BAD_RECORD;
 		*err_info = g_strdup("airopeekv9: record has two timestamp-upper fields");
-		return FALSE;
+		return 0;
 	    }
 	    hdr_info->timestamp.upper = pletohl(&tag_value[2]);
 	    saw_timestamp_upper = TRUE;
@@ -456,17 +460,17 @@ airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
     if (!saw_length) {
 	*err = WTAP_ERR_BAD_RECORD;
 	*err_info = g_strdup("airopeekv9: record has no length field");
-	return FALSE;
+	return 0;
     }
     if (!saw_timestamp_lower) {
 	*err = WTAP_ERR_BAD_RECORD;
 	*err_info = g_strdup("airopeekv9: record has no timestamp-lower field");
-	return FALSE;
+	return 0;
     }
     if (!saw_timestamp_upper) {
 	*err = WTAP_ERR_BAD_RECORD;
 	*err_info = g_strdup("airopeekv9: record has no timestamp-upper field");
-	return FALSE;
+	return 0;
     }
 
     return header_len;
@@ -485,6 +489,7 @@ airopeekv9_process_header(FILE_T fh, hdr_info_t *hdr_info, int *err,
 static gboolean airopeekv9_read(wtap *wth, int *err, gchar **err_info,
     gint64 *data_offset)
 {
+    airopeek9_t *airopeek9 = (airopeek9_t *)wth->priv;
     hdr_info_t hdr_info;
     int hdrlen;
     double  t;
@@ -493,7 +498,7 @@ static gboolean airopeekv9_read(wtap *wth, int *err, gchar **err_info,
 
     /* Process the packet header. */
     hdrlen = airopeekv9_process_header(wth->fh, &hdr_info, err, err_info);
-    if (hdrlen == -1)
+    if (hdrlen == 0)
 	return FALSE;
     wth->data_offset += hdrlen;
 
@@ -534,7 +539,7 @@ static gboolean airopeekv9_read(wtap *wth, int *err, gchar **err_info,
 	 * whether to supply it as an FCS or discard it.
 	 */
 	wth->pseudo_header.ieee_802_11 = hdr_info.ieee_802_11;
-	if (wth->capture.airopeek9->has_fcs)
+	if (airopeek9->has_fcs)
 	    wth->pseudo_header.ieee_802_11.fcs_len = 4;
 	else {
 	    wth->pseudo_header.ieee_802_11.fcs_len = 0;
@@ -563,6 +568,7 @@ airopeekv9_seek_read(wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header, guchar *pd, int length,
     int *err, gchar **err_info)
 {
+    airopeek9_t *airopeek9 = (airopeek9_t *)wth->priv;
     hdr_info_t hdr_info;
 
     if (file_seek(wth->random_fh, seek_off, SEEK_SET, err) == -1)
@@ -576,7 +582,7 @@ airopeekv9_seek_read(wtap *wth, gint64 seek_off,
 
     case WTAP_ENCAP_IEEE_802_11_WITH_RADIO:
 	pseudo_header->ieee_802_11 = hdr_info.ieee_802_11;
-	if (wth->capture.airopeek9->has_fcs)
+	if (airopeek9->has_fcs)
 	    pseudo_header->ieee_802_11.fcs_len = 4;
 	else
 	    pseudo_header->ieee_802_11.fcs_len = 0;
@@ -594,9 +600,3 @@ airopeekv9_seek_read(wtap *wth, gint64 seek_off,
     wtap_file_read_expected_bytes(pd, length, wth->random_fh, err);
     return TRUE;
 }
-
-static void
-airopeekv9_close(wtap *wth)
-{
-    g_free(wth->capture.airopeek9);
-}
